@@ -28,14 +28,15 @@ namespace KFileMetaData
 class EPubExtractor : public ExtractorPlugin
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA(IID "org.kde.kf5.kfilemetadata.ExtractorPlugin")
+    Q_PLUGIN_METADATA(IID "org.kde.kf5.kfilemetadata.ExtractorPlugin"
+                      FILE "epubextractor.json")
     Q_INTERFACES(KFileMetaData::ExtractorPlugin)
 
 public:
     explicit EPubExtractor(QObject* parent = nullptr);
 
-    void extract(ExtractionResult* result) Q_DECL_OVERRIDE;
-    QStringList mimetypes() const Q_DECL_OVERRIDE;
+    void extract(ExtractionResult* result) override;
+    QStringList mimetypes() const override;
 };
 }
 
